# Remote Py

Remote Py allows you to write python functions and run it on a server. It also provides you interfaces in multiple languages including JavaScript, CSharp and Python to call the remote python functions.

It is a RPC mechanism built on top of Web Sockets allowing you to communicate both ways. 

Requirements:
Please make sure following packages are installed.
numpy
service_identity
twisted
autobahn

Installation instructions:
pip install numpy
pip install autobahn[twisted]

More details coming soon ...